/**
 * Point geometry object.
 * https://tools.ietf.org/html/rfc7946#section-3.1.2
 */
export declare type Point = {
    type: "Point";
    coordinates: number[];
};
/**
 * LineString geometry object.
 * https://tools.ietf.org/html/rfc7946#section-3.1.4
 */
export declare type LineString = {
    type: "LineString";
    coordinates: number[][];
};
/**
 * Polygon geometry object.
 * https://tools.ietf.org/html/rfc7946#section-3.1.6
 */
export declare type Polygon = {
    type: "Polygon";
    coordinates: number[][][];
};
/**
 * MultiPoint geometry object.
 *  https://tools.ietf.org/html/rfc7946#section-3.1.3
 */
export declare type MultiPoint = {
    type: "MultiPoint";
    coordinates: number[][];
};
/**
 * MultiLineString geometry object.
 * https://tools.ietf.org/html/rfc7946#section-3.1.5
 */
export declare type MultiLineString = {
    type: "MultiLineString";
    coordinates: number[][][];
};
/**
 * MultiPolygon geometry object.
 * https://tools.ietf.org/html/rfc7946#section-3.1.7
 */
export declare type MultiPolygon = {
    type: "MultiPolygon";
    coordinates: number[][][][];
};
/**
 * Geometry Collection
 * https://tools.ietf.org/html/rfc7946#section-3.1.8
 */
export declare type GeometryCollection = {
    type: "GeometryCollection";
    geometries: (Point | LineString | Polygon | MultiPoint | MultiLineString | MultiPolygon)[];
};
/**
 * Union of Geometry objects.
 */
export declare type Geometry = Point | LineString | Polygon | MultiPoint | MultiLineString | MultiPolygon | GeometryCollection;
export declare type Geography = Geometry;
/**
 * A feature object which contains a geometry and associated properties.
 * https://tools.ietf.org/html/rfc7946#section-3.2
 */
export declare type Feature = {
    type: "Feature";
    geometry: Geometry;
    id?: string | number;
    bbox?: number[];
    properties: {
        [name: string]: any;
    } | null;
};
/**
 * A collection of feature objects.
 *  https://tools.ietf.org/html/rfc7946#section-3.3
 */
export declare type FeatureCollection = {
    type: "FeatureCollection";
    bbox?: number[];
    features: Feature[];
};
/**
 * Union of GeoJSON objects.
 */
export declare type GeoJSON = Geometry | Feature | FeatureCollection;
